@@ -15,13 +15,13 @@ from python_rules_evaluator.modules.jsongeek import dotpath_get_value, dotpath_e
 class Evaluator():
     RE_VAR = r"\$([^ '\"\), ]+)"
 
-    def __init__(self, rules: Union[str, dict], functions: dict = {}):
+    def __init__(self, rules: Union[str, list], functions: dict = {}):
         self.functions = functions
         if isinstance(rules, str):
             self.rules_file = rules
             with open(join(str(Path().absolute()), rules)) as rules_file:
                 self.rules = yaml.load(rules_file, Loader=yaml.FullLoader)
-        elif isinstance(rules, dict):
+        elif isinstance(rules, list):
             self.rules_file = 'no file, loaded from object'
             self.rules = rules
 
@@ -290,6 +290,5 @@ class Evaluator():
 
         except Exception as ex:
             rules_file = re.sub(r".*\/", "", self.rules_file)
-            # pp(ex)
             log.error(f"{rules_file}: {ex}")
             traceback.print_exc(file=stdout)
